/**
 * 设备列表页
 *
 * */

import React, { useEffect, useState } from 'react'
import { ScrollView, View, Text, SafeAreaView, NativeModules, FlatList, StatusBar } from 'react-native';
// import Tabbar from '../../components/Tabbar';
import { equiment as equimentServices } from '../../services';
import styles from './style';

const { BMCInfo: { getLoginInfo }, BMCUI } = NativeModules;

const Equipment = () => {
  const [equimentList, setEquimentList] = useState([]);
  useEffect(() => {
    getEquimentList();
  }, []);//seEffect Hook 看做 componentDidMount，componentDidUpdate 和 componentWillUnmount 这三个函数的组合,传递一个空数组（[]）作为第二个参数。
  //这就告诉 React 你的 effect 不依赖于 props 或 state 中的任何值，所以它永远都不需要重复执行。即只运行一次的 effect（仅在组件挂载和卸载时执行）
  //[count]即仅在 count 更改时更新

  const getEquimentList = async () => {
    try {
      const data = await equimentServices.getBindEquipmentList();
      setEquimentList(data[0].devices || []);
    } catch (e) {
      BMCUI.showToast(e && e.message);
      console.log("error:")
      console.log(e)
    }
  };

  return (
    <SafeAreaView style={styles.container}>
      <StatusBar translucent={false} backgroundColor='#fff' barStyle="dark-content" />
      <FlatList
        style={styles.content}
        data={equimentList}
        keyExtractor={(item, index) => item.deviceId + ''}
        ListHeaderComponent={() => {
          return <Text style={styles.tip}>
            列表呈现用户登录的常用设备，以及在常用设备上的最后登录时间
          </Text>
        }}
        renderItem={({ item }) => {
          return <View style={styles.ceil}>
            <View style={styles.ceilTitle}>
              <Text style={styles.ceilName}>{item.title}</Text>
              {item.currentDevice && <Text style={styles.ceilTag}>本机</Text>}
            </View>
            <Text style={styles.ceilInfo}>最后登录时间：{item.gmtLoginDisplay}</Text>
          </View>;
        }}
      />
    </SafeAreaView>
  )
};

export default Equipment
