import React from 'react'
import { NavigationContainer } from '@react-navigation/native';
import { NativeModules, Image, View } from 'react-native';
import { createStackNavigator, HeaderBackButton } from '@react-navigation/stack';
import { IC_BACK_BLACK } from '../assets/images'
import { HEADER_HEIGHT } from '../config'
import Equipment from '../pages/Equipment'
import ChangeNickname from '../pages/ChangeNickname'

const Stack = createStackNavigator();
const { BMCAction: { exit } } = NativeModules;

const pathMap = {
  '/equiment': 'equiment',
  '/changeNickname': 'changeNickname',
};

function AllStack(props) {
  const { path } = props;
  const headerLeft = (props) => (
    <HeaderBackButton
      {...props}
      backImage={() => (
        <View style={{ paddingStart: 5, paddingEnd: 10, paddingTop: 10, paddingBottom: 10 }}>
          <Image source={IC_BACK_BLACK} style={{ width: 10, height: 18 }} />
        </View>
      )}
      onPress={() => {
        exit()
      }}
    />
  );

  return (
    <Stack.Navigator initialRouteName={pathMap[path] || 'changeNickname'}
      screenOptions={{
        headerLeft: headerLeft,
        headerStyle: {
          height: HEADER_HEIGHT, // Specify the height of your custom header
        },
        headerTitleStyle: {
          alignItems: "center",
          fontSize: 18
        },
        headerTitleAlign: "center"
      }}>
      <Stack.Screen options={{ title: '常用设备', }} name="equiment" component={Equipment} />
      <Stack.Screen options={{ title: '修改昵称' }} name="changeNickname" component={ChangeNickname} />
    </Stack.Navigator>
  );
}

export default function App(props) {
  const { path } = props;
  return (
    <NavigationContainer>
      <AllStack path={path} />
    </NavigationContainer>
  );
}
